@@ -9,6 +9,7 @@ use Types::Standard -all;
 use GraphQL::Type::Library -all;
 use Return::Type;
 use Function::Parameters;
+use GraphQL::Debug qw(_debug);
 extends qw(GraphQL::Type);
 with qw(
   GraphQL::Role::Output
@@ -18,6 +19,8 @@ with qw(
   GraphQL::Role::Named
 );
 
+use constant DEBUG => $ENV{GRAPHQL_DEBUG};
+
 our $VERSION = '0.02';
 
 =head1 NAME
@@ -74,13 +77,14 @@ performing validation.
 has _types_validated => (is => 'rw', isa => Bool);
 method get_types() :ReturnType(ArrayRefNonEmpty[InstanceOf['GraphQL::Type::Object']]) {
   my @types = @{ $self->types };
-  return @types if $self->_types_validated; # only do once
+  return \@types if $self->_types_validated; # only do once
+  $self->_types_validated(1);
   if (!$self->resolve_type) {
     my @bad = map $_->name, grep !$_->is_type_of, @types;
     die $self->name." no resolve_type and no is_type_of for @bad" if @bad;
   }
-  $self->_types_validated(1);
-  @types;
+  DEBUG and _debug('get_types', $self->name, \@types);
+  \@types;
 }
 
 __PACKAGE__->meta->make_immutable();
